@@ -8,12 +8,12 @@ use Log::ger;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-27'; # DATE
+our $DATE = '2023-02-11'; # DATE
 our $DIST = 'App-BPOMUtils-RPO-Checker'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our @EXPORT_OK = qw(
-                       bpom_rpo_check_label_design
+                       bpom_rpo_check_label_files_design
                );
 
 our %SPEC;
@@ -23,7 +23,63 @@ $SPEC{':package'} = {
     summary => 'Various checker utilities to help with Processed Food Registration (RPO - Registrasi Pangan Olahan) at BPOM',
 };
 
-$SPEC{bpom_rpo_check_label_design} = {
+$SPEC{bpom_rpo_check_files} = {
+    v => 1.1,
+    summary => 'Check document files',
+    description => <<'_',
+
+By default will check all files in the current directory, recursively.
+
+Here's what it checks:
+- filename should not contain unsafe symbols
+- file must not be larger than 5MB
+- file must be readable
+
+_
+    args => {
+        files => {
+            schema => ['array*', of=>'filename', 'x.perl.default_value_rules' => [['Path::filenames']]],
+            pos => 0,
+            slurpy => 1,
+        },
+    },
+};
+sub bpom_rpo_check_files {
+    my %args = @_;
+
+    my $i = 0;
+    my @errors;
+    my @warnings;
+    for my $file (@{ $args{files} }) {
+        $i++;
+        log_info "[%d/%d] Processing file %s ...", $i, scalar(@{ $args{files} }), $file;
+        unless (-f $file) {
+            push @errors, {file=>$file, message=>"File not found or not a regular file"};
+            next;
+        }
+
+        if ($file =~ /\.[^.]+\./) {
+            push @errors, {file=>$file, message=>"Filename contains multiple dots, currently uploadable but not viewable in ereg-rba"};
+        }
+        if ($file =~ /[^A-Za-z0-9_.-]/) {
+            push @warnings, {file=>$file, message=>"Filename contains symbols, should be avoided to ensure viewable in ereg-rba"};
+        }
+
+        if (!-r($file)) {
+            push @errors, {file=>$file, message=>"File cannot be read"};
+            next;
+        }
+
+        my $filesize = -s $file;
+        if ($filesize > 5*1024*1024) {
+            push @errors, {file=>$file, message=>"File size too large (>5M)"};
+        }
+    }
+
+    [200, "OK", [@errors, @warnings], {'cmdline.exit_code'=>@errors ? 1:0}];
+}
+
+$SPEC{bpom_rpo_check_files_label_design} = {
     v => 1.1,
     summary => 'Check label design files',
     description => <<'_',
@@ -32,7 +88,9 @@ By default will check all files in the current directory, recursively.
 
 Here's what it checks:
 - file must be in JPEG format and has name ending in /\.jpe?g$/i
+- filename should not contain unsafe symbols
 - file must not be larger than 5MB
+- file must be readable
 - image size must not be larger than 2300 x 2300 px
 - (WARNING) image should not be smaller than 600 x 600 px
 
@@ -45,7 +103,7 @@ _
         },
     },
 };
-sub bpom_rpo_check_label_design {
+sub bpom_rpo_check_files_label_design {
     require File::MimeInfo::Magic;
     require Image::Size;
 
@@ -61,9 +119,17 @@ sub bpom_rpo_check_label_design {
             push @errors, {file=>$file, message=>"File not found or not a regular file"};
             next;
         }
+
         unless ($file =~ /\.jpe?g\z/i) {
             push @errors, {file=>$file, message=>"Filename does not end in .JPG or .JPEG"};
         }
+        if ($file =~ /\.[^.]+\./) {
+            push @errors, {file=>$file, message=>"Filename contains multiple dots, currently uploadable but not viewable in ereg-rba"};
+        }
+        if ($file =~ /[^A-Za-z0-9_.-]/) {
+            push @warnings, {file=>$file, message=>"Filename contains symbols, should be avoided to ensure viewable in ereg-rba"};
+        }
+
         if (!-r($file)) {
             push @errors, {file=>$file, message=>"File cannot be read"};
             next;
@@ -108,7 +174,7 @@ App::BPOMUtils::RPO::Checker - Various checker utilities to help with Processed
 
 =head1 VERSION
 
-This document describes version 0.004 of App::BPOMUtils::RPO::Checker (from Perl distribution App-BPOMUtils-RPO-Checker), released on 2023-01-27.
+This document describes version 0.005 of App::BPOMUtils::RPO::Checker (from Perl distribution App-BPOMUtils-RPO-Checker), released on 2023-02-11.
 
 =head1 SYNOPSIS
 
@@ -119,18 +185,61 @@ Registration (RPO - Registrasi Pangan Olahan).
 
 =over
 
-=item * L<bpom-rpo-check-label-design>
+=item * L<bpom-rpo-check-files>
+
+=item * L<bpom-rpo-check-files-label-design>
 
 =back
 
 =head1 FUNCTIONS
 
 
-=head2 bpom_rpo_check_label_design
+=head2 bpom_rpo_check_files
 
 Usage:
 
- bpom_rpo_check_label_design(%args) -> [$status_code, $reason, $payload, \%result_meta]
+ bpom_rpo_check_files(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+Check document files.
+
+By default will check all files in the current directory, recursively.
+
+Here's what it checks:
+- filename should not contain unsafe symbols
+- file must not be larger than 5MB
+- file must be readable
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<files> => I<array[filename]>
+
+(No description)
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
+
+
+=head2 bpom_rpo_check_files_label_design
+
+Usage:
+
+ bpom_rpo_check_files_label_design(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check label design files.
 
@@ -138,11 +247,13 @@ By default will check all files in the current directory, recursively.
 
 Here's what it checks:
 - file must be in JPEG format and has name ending in /.jpe?g$/i
+- filename should not contain unsafe symbols
 - file must not be larger than 5MB
+- file must be readable
 - image size must not be larger than 2300 x 2300 px
 - (WARNING) image should not be smaller than 600 x 600 px
 
-This function is not exported by default, but exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
